@@ -24,7 +24,7 @@ sexp* r_f_lhs(sexp* f) {
   }
 }
 sexp* r_f_env(sexp* f) {
-  return r_get_attribute(f, r_sym(".Environment"));
+  return r_attrib_get(f, r_sym(".Environment"));
 }
 
 bool r_f_has_env(sexp* f) {
@@ -33,7 +33,7 @@ bool r_f_has_env(sexp* f) {
 
 bool r_is_formula(sexp* x, int scoped, int lhs) {
   if (r_is_formulaish(x, scoped, lhs)) {
-    return r_node_car(x) == r_tilde_sym;
+    return r_node_car(x) == r_syms_tilde;
   } else {
     return false;
   }
@@ -89,7 +89,7 @@ sexp* new_raw_formula(sexp* lhs, sexp* rhs, sexp* env) {
 
   sexp* attrs = KEEP(r_new_node(env, r_null));
   r_node_poke_tag(attrs, r_sym(".Environment"));
-  r_poke_attributes(f, attrs);
+  r_poke_attrib(f, attrs);
 
   FREE(3);
   return f;
